# Oops, I did it again

Ein unerwarteter Fehler ist aufgetreten. Möchtest Du einen Fehlerbericht senden? Das passiert automatisch und hilft uns dabei den Fehler in Zukunft zu verhindern.

[Sende Fehlerbericht](opensesame://event.bug_report_send){: .important-button}

Datenschutz:

- Der Fehlerbericht (siehe unten) könnte persönliche Informationen, wie zum Beispiel Deinen Benutzernamen, enthalten. Sollte das der Fall sein, wird diese Information für keinen anderen Zweck als die Behebung von Fehlern verwendet.

Information:

- Betriebssystem: %(platform)s
- OpenSesame: %(version)s
- Python: %(python_version)s

Hör' auf mir diese Nachricht zu zeigen!

- Wenn Du in Zukunft keine Benachrichtigungen zu Fehlerberichten mehr sehen willst, kannst Du das bug_report-Plugin unter Menü → Werkzeuge → Plugin- und Erweiterungsmanager deaktivieren. Das behebt aber nicht das Problem -- es unterdrückt nur die Fehlermeldung!

Fehlermeldung:

%(traceback)s
